const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    const vars = context.steps;

    let childInventory = vars.shopify.available;
    let currentParentInventory = vars.shopify_3.inventory_quantity;
    let newParentInventory = this.newParentInventory(vars);

    Mesa.trigger.setTaskExternalData({
      "label": `Child Inventory: ${childInventory}, 
                Parent Current: ${currentParentInventory},
                Parent New: ${newParentInventory}`
    });

    Mesa.output.next({"available": newParentInventory});
  }

  newParentInventory = (vars) => {
    const skuToQuantityObject = vars.custom_2;

    let lowestQuantity = Number.MAX_SAFE_INTEGER;
    let childQuantityPerBundle = null;
    let childQuantityDivided = null;

    for (const [sku, childQuantity] of Object.entries(skuToQuantityObject)) {
      childQuantityPerBundle = this.childQuantityPerBundle(vars, sku);
      childQuantityDivided = Math.floor(childQuantity / childQuantityPerBundle);
      Mesa.log.info(`=============
        Child quantity per bundle: ${sku} - quantity: ${childQuantity}, quantity per bundle: ${childQuantityPerBundle}, divided: ${childQuantityDivided}`
      );
      if (childQuantityDivided < lowestQuantity) {
        lowestQuantity = childQuantityDivided;
      }
    }

    return lowestQuantity;
  }

  childQuantityPerBundle(vars, childSku) {
    const childSkuToQuantityObject = vars.custom_3.reduce((accumulator, item) => {
      const { "Child SKU": childSku, "Child Quantity": childQuantity } = item.data;
      accumulator[childSku] = childQuantity;
      return accumulator;
    }, {});

    return childSkuToQuantityObject[childSku];
  }
}
